@@ -1,6 +1,5 @@
 import os
 
-# __name__ ='pygwbl'
 __all__=["svg2emf","about"]
 
 
@@ -10,3 +9,7 @@ def svg2emf(FileName):
 def about():
     print("Hi, I am Dagwbl. ")
 
+if __name__=="__main__":
+    print('pygwbl: running by myself')
+else:
+    print('pygwbl: I am being imported from other module')
